@@ -8,9 +8,13 @@ LOGGER.addFilter(warning_filter)
 def warning(message: str) -> None:
     LOGGER.warning(f"[auto-tags] {message}")
 
+
+def debug(message: str, *args) -> None:
+    LOGGER.debug(f"[auto-tags] {message}", *args)
+
 # Import local files in the correct order
 # from .utils import replace_regex_matches
 # from .normal_badge import replace_normal_badges
-from .plugin import BadgesPlugin
+from .plugin import Plugin
 
-__all__ = ["BadgesPlugin"]
+__all__ = ["Plugin"]
